@@ -4,7 +4,7 @@ from pandas.errors import EmptyDataError
 
 
 class Ptrms:
-    def __init__(self, file, ref_start, ref_end, sample_start, sample_end):
+    def __init__(self, file, ref_start, ref_end, sample_start, sample_end, threshold):
         self.file = file
         self.ref_start = ref_start
         self.ref_end = ref_end
@@ -12,6 +12,11 @@ class Ptrms:
         self.sample_end = sample_end
         self.frame = pd.DataFrame
         self.errors = []
+        self.threshold = int(threshold)
+        self.dif = pd.DataFrame
+        self.out_path = lambda x: os.path.join(
+            os.path.dirname(self.file.name), x
+        )
 
     def run(self):
         self.load()
@@ -49,18 +54,30 @@ class Ptrms:
 
     def extract_windows(self):
         ref_window_stats = (
-            self.frame.loc[int(self.ref_start) - 1 : int(self.ref_end)]
-            .drop(columns=["Cycle"], errors="ignore")
-            .describe()
+            self.frame.loc[int(self.ref_start) - 1: int(self.ref_end)]
+                .drop(columns=["Cycle"], errors="ignore")
+                .describe()
         )
         sample_window_stats = (
-            self.frame.loc[int(self.sample_start) - 1 : int(self.sample_end)]
-            .drop(columns=["Cycle"], errors="ignore")
-            .describe()
+            self.frame.loc[int(self.sample_start) - 1: int(self.sample_end)]
+                .drop(columns=["Cycle"], errors="ignore")
+                .describe()
         )
 
-        dif_stats = sample_window_stats.transpose().sub(ref_window_stats.transpose())
-        out_path = os.path.join(
-            os.path.dirname(self.file.name), "extracted_window.xlsx"
-        )
-        dif_stats.to_excel(out_path)
+        self.dif = sample_window_stats.transpose().sub(ref_window_stats.transpose())
+        out_path = self.out_path(f"extracted_window.xlsx")
+        try:
+            self.dif.to_excel(out_path)
+        except PermissionError as e:
+            self.errors.append('Unable to write window data, the file may be open')
+        if self.threshold:
+            self.threshold_extract()
+
+    def threshold_extract(self):
+        rows = self.dif[self.dif['max'] > self.threshold].index
+        thresh_data = self.frame[rows]
+        out_path = self.out_path(f'Extracted Threshold {self.threshold}.xlsx')
+        try:
+            thresh_data.to_excel(out_path)
+        except PermissionError as e:
+            self.errors.append('Unable to write threshold data, the file may be open')
\ No newline at end of file
